summaryrefslogtreecommitdiffstats
path: root/src/configdialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-02 06:40:27 +0000
commit2595a15ebeb6fc46b7cb241d01ec0c2460ec2111 (patch)
tree18a8f0f4ac5a86dacfa74c3537551ec39bc85e75 /src/configdialog.h
parent1d90725a4001fab9d3922b2cbcceeee5e2d1686f (diff)
downloadtellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.tar.gz
tellico-2595a15ebeb6fc46b7cb241d01ec0c2460ec2111.zip
TQt4 port tellico
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/tellico@1239054 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/configdialog.h')
-rw-r--r--src/configdialog.h61
1 files changed, 31 insertions, 30 deletions
diff --git a/src/configdialog.h b/src/configdialog.h
index 64b5dbf..4bf0fe5 100644
--- a/src/configdialog.h
+++ b/src/configdialog.h
@@ -27,8 +27,8 @@ class KIntNumInput;
class KFontCombo;
class KColorCombo;
-class QCheckBox;
-class QRadioButton;
+class TQCheckBox;
+class TQRadioButton;
namespace Tellico {
class SourceListViewItem;
@@ -47,15 +47,16 @@ namespace Tellico {
*/
class ConfigDialog : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor sets up the Tabbed dialog pages.
*
* @param parent A pointer to the parent widget
* @param name The widget name
*/
- ConfigDialog(QWidget* parent, const char* name=0);
+ ConfigDialog(TQWidget* tqparent, const char* name=0);
virtual ~ConfigDialog();
/**
@@ -99,9 +100,9 @@ private slots:
/**
* Update the help link for a page.
*
- QCheckBox* m_cbWriteImagesInFile; * @param w The page
+ TQCheckBox* m_cbWriteImagesInFile; * @param w The page
*/
- void slotUpdateHelpLink(QWidget* w);
+ void slotUpdateHelpLink(TQWidget* w);
/**
* Create a new Internet source
*/
@@ -114,7 +115,7 @@ private slots:
* Remove a Internet source
*/
void slotRemoveSourceClicked();
- void slotSelectedSourceChanged(QListViewItem* item);
+ void slotSelectedSourceChanged(TQListViewItem* item);
void slotMoveUpSourceClicked();
void slotMoveDownSourceClicked();
void slotNewStuffClicked();
@@ -145,27 +146,27 @@ private:
*/
void readFetchConfig();
- SourceListViewItem* findItem(const QString& path) const;
+ SourceListViewItem* findItem(const TQString& path) const;
void loadTemplateList();
bool m_modifying;
bool m_okClicked;
- QRadioButton* m_rbImageInFile;
- QRadioButton* m_rbImageInAppDir;
- QRadioButton* m_rbImageInLocalDir;
- QCheckBox* m_cbOpenLastFile;
- QCheckBox* m_cbShowTipDay;
- QCheckBox* m_cbCapitalize;
- QCheckBox* m_cbFormat;
+ TQRadioButton* m_rbImageInFile;
+ TQRadioButton* m_rbImageInAppDir;
+ TQRadioButton* m_rbImageInLocalDir;
+ TQCheckBox* m_cbOpenLastFile;
+ TQCheckBox* m_cbShowTipDay;
+ TQCheckBox* m_cbCapitalize;
+ TQCheckBox* m_cbFormat;
KLineEdit* m_leCapitals;
KLineEdit* m_leArticles;
KLineEdit* m_leSuffixes;
KLineEdit* m_lePrefixes;
- QCheckBox* m_cbPrintHeaders;
- QCheckBox* m_cbPrintFormatted;
- QCheckBox* m_cbPrintGrouped;
+ TQCheckBox* m_cbPrintHeaders;
+ TQCheckBox* m_cbPrintFormatted;
+ TQCheckBox* m_cbPrintGrouped;
KIntSpinBox* m_imageWidthBox;
KIntSpinBox* m_imageHeightBox;
@@ -179,9 +180,9 @@ private:
KColorCombo* m_highTextColorCombo;
KListView* m_sourceListView;
- QMap<SourceListViewItem*, Fetch::ConfigWidget*> m_configWidgets;
- QPtrList<Fetch::ConfigWidget> m_newStuffConfigWidgets;
- QPtrList<Fetch::ConfigWidget> m_removedConfigWidgets;
+ TQMap<SourceListViewItem*, Fetch::ConfigWidget*> m_configWidgets;
+ TQPtrList<Fetch::ConfigWidget> m_newStuffConfigWidgets;
+ TQPtrList<Fetch::ConfigWidget> m_removedConfigWidgets;
KPushButton* m_modifySourceBtn;
KPushButton* m_moveUpSourceBtn;
KPushButton* m_moveDownSourceBtn;
@@ -191,22 +192,22 @@ private:
class GeneralFetcherInfo {
public:
- GeneralFetcherInfo(Fetch::Type t, const QString& n, bool o) : type(t), name(n), updateOverwrite(o) {}
+ GeneralFetcherInfo(Fetch::Type t, const TQString& n, bool o) : type(t), name(n), updateOverwrite(o) {}
Fetch::Type type;
- QString name;
+ TQString name;
bool updateOverwrite : 1;
};
class SourceListViewItem : public KListViewItem {
public:
- SourceListViewItem(KListView* parent, const GeneralFetcherInfo& info,
- const QString& groupName = QString::null);
+ SourceListViewItem(KListView* tqparent, const GeneralFetcherInfo& info,
+ const TQString& groupName = TQString());
- SourceListViewItem(KListView* parent, QListViewItem* after,
- const GeneralFetcherInfo& info, const QString& groupName = QString::null);
+ SourceListViewItem(KListView* tqparent, TQListViewItem* after,
+ const GeneralFetcherInfo& info, const TQString& groupName = TQString());
- void setConfigGroup(const QString& s) { m_configGroup = s; }
- const QString& configGroup() const { return m_configGroup; }
+ void setConfigGroup(const TQString& s) { m_configGroup = s; }
+ const TQString& configGroup() const { return m_configGroup; }
const Fetch::Type& fetchType() const { return m_info.type; }
void setUpdateOverwrite(bool b) { m_info.updateOverwrite = b; }
bool updateOverwrite() const { return m_info.updateOverwrite; }
@@ -217,7 +218,7 @@ public:
private:
GeneralFetcherInfo m_info;
- QString m_configGroup;
+ TQString m_configGroup;
bool m_newSource : 1;
Fetch::Fetcher::Ptr m_fetcher;
};
@@ -47,15 +47,16 @@ namespace Tellico {
* The constructor sets up the Tabbed dialog pages.
*
- * @param parent A pointer to the parent widget
+ * @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/